@@ -205,9 +205,10 @@ def get_blocklisted_functions() -> dict[str, set[str]] | dict[str, Any]:
     if pr_number is None:
         return {}
 
-    owner, repo = get_repo_owner_and_name()
-    information = {"pr_number": pr_number, "repo_owner": owner, "repo_name": repo}
     try:
+        owner, repo = get_repo_owner_and_name()
+        information = {"pr_number": pr_number, "repo_owner": owner, "repo_name": repo}
+
         req = make_cfapi_request(endpoint="/verify-existing-optimizations", method="POST", payload=information)
         req.raise_for_status()
         content: dict[str, list[str]] = req.json()
@@ -260,3 +261,16 @@ def mark_optimization_success(trace_id: str, *, is_optimization_found: bool) ->
     """
     payload = {"trace_id": trace_id, "is_optimization_found": is_optimization_found}
     return make_cfapi_request(endpoint="/mark-as-success", method="POST", payload=payload)
+
+
+def send_completion_email() -> Response:
+    """Send an email notification when codeflash --all completes."""
+    try:
+        owner, repo = get_repo_owner_and_name()
+    except Exception as e:
+        sentry_sdk.capture_exception(e)
+        response = requests.Response()
+        response.status_code = 500
+        return response
+    payload = {"owner": owner, "repo": repo}
+    return make_cfapi_request(endpoint="/send-completion-email", method="POST", payload=payload)
