@@ -1,4 +1,6 @@
+# ruff: noqa
 import sys
+from typing import Any
 
 # This script should not have any relation to the codeflash package, be careful with imports
 cwd = sys.argv[1]
@@ -15,9 +17,15 @@ class PytestCollectionPlugin:
         collected_tests.extend(session.items)
         pytest_rootdir = session.config.rootdir
 
+    def pytest_collection_modifyitems(self, items) -> None:
+        skip_benchmark = pytest.mark.skip(reason="Skipping benchmark tests")
+        for item in items:
+            if "benchmark" in item.fixturenames:
+                item.add_marker(skip_benchmark)
 
-def parse_pytest_collection_results(pytest_tests: list[any]) -> list[dict[str, str]]:
-    test_results: list[list[str]] = []
+
+def parse_pytest_collection_results(pytest_tests: list[Any]) -> list[dict[str, str]]:
+    test_results = []
     for test in pytest_tests:
         test_class = None
         if test.cls:
@@ -27,11 +35,13 @@ def parse_pytest_collection_results(pytest_tests: list[any]) -> list[dict[str, s
 
 
 if __name__ == "__main__":
+    from pathlib import Path
+
     import pytest
 
     try:
         exitcode = pytest.main(
-            [tests_root, "-pno:logging", "--collect-only", "-m", "not skip"], plugins=[PytestCollectionPlugin()]
+            [tests_root, "-p no:logging", "--collect-only", "-m", "not skip"], plugins=[PytestCollectionPlugin()]
         )
     except Exception as e:
         print(f"Failed to collect tests: {e!s}")
@@ -39,5 +49,5 @@ if __name__ == "__main__":
     tests = parse_pytest_collection_results(collected_tests)
     import pickle
 
-    with open(pickle_path, "wb") as f:
+    with Path(pickle_path).open("wb") as f:
         pickle.dump((exitcode, tests, pytest_rootdir), f, protocol=pickle.HIGHEST_PROTOCOL)
